==> eam-wshub-proxyclient-11.4-8-sources.jar: net/datastream/schemas/mp_fields/VMRSSTRUCTURECODEID.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}VMRSSTRUCTURECODE"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "vmrsstructurecode"
})
@XmlRootElement(name = "VMRSSTRUCTURECODEID")
public class VMRSSTRUCTURECODEID {

    @XmlElement(name = "VMRSSTRUCTURECODE", required = true)
    protected String vmrsstructurecode;

    /**
     * Obtient la valeur de la propriété vmrsstructurecode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVMRSSTRUCTURECODE() {
        return vmrsstructurecode;
    }

    /**
     * Définit la valeur de la propriété vmrsstructurecode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVMRSSTRUCTURECODE(String value) {
        this.vmrsstructurecode = value;
    }

}

==> eam-wshub-proxyclient-12.1-0-sources.jar: net/datastream/schemas/mp_fields/VMRSSTRUCTURECODEID.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}VMRSSTRUCTURECODE"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "vmrsstructurecode"
})
@XmlRootElement(name = "VMRSSTRUCTURECODEID")
public class VMRSSTRUCTURECODEID {

    @XmlElement(name = "VMRSSTRUCTURECODE", required = true)
    protected String vmrsstructurecode;

    /**
     * Gets the value of the vmrsstructurecode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVMRSSTRUCTURECODE() {
        return vmrsstructurecode;
    }

    /**
     * Sets the value of the vmrsstructurecode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVMRSSTRUCTURECODE(String value) {
        this.vmrsstructurecode = value;
    }

}
